==> cloudformation-1.60.0-sources.jar: software/amazon/awscdk/services/cloudformation/CloudFormationCapabilities.java <==
package software.amazon.awscdk.services.cloudformation;

/**
 * Capabilities that affect whether CloudFormation is allowed to change IAM resources.
 * <p>
 * @deprecated use `core.CfnCapabilities`
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.361Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudformation.$Module.class, fqn = "@aws-cdk/aws-cloudformation.CloudFormationCapabilities")
public enum CloudFormationCapabilities {
    /**
     * No IAM Capabilities.
     * <p>
     * Pass this capability if you wish to block the creation IAM resources.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    NONE,
    /**
     * Capability to create anonymous IAM resources.
     * <p>
     * Pass this capability if you're only creating anonymous resources.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    ANONYMOUS_IAM,
    /**
     * Capability to create named IAM resources.
     * <p>
     * Pass this capability if you're creating IAM resources that have physical
     * names.
     * <p>
     * <code>CloudFormationCapabilities.NamedIAM</code> implies <code>CloudFormationCapabilities.IAM</code>; you don't have to pass both.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    NAMED_IAM,
    /**
     * Capability to run CloudFormation macros.
     * <p>
     * Pass this capability if your template includes macros, for example AWS::Include or AWS::Serverless.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    AUTO_EXPAND,
}

==> cloudformation-1.104.0-sources.jar: software/amazon/awscdk/services/cloudformation/CloudFormationCapabilities.java <==
package software.amazon.awscdk.services.cloudformation;

/**
 * (deprecated) Capabilities that affect whether CloudFormation is allowed to change IAM resources.
 * <p>
 * @deprecated use `core.CfnCapabilities`
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:08.327Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudformation.$Module.class, fqn = "@aws-cdk/aws-cloudformation.CloudFormationCapabilities")
public enum CloudFormationCapabilities {
    /**
     * (deprecated) No IAM Capabilities.
     * <p>
     * Pass this capability if you wish to block the creation IAM resources.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    NONE,
    /**
     * (deprecated) Capability to create anonymous IAM resources.
     * <p>
     * Pass this capability if you're only creating anonymous resources.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    ANONYMOUS_IAM,
    /**
     * (deprecated) Capability to create named IAM resources.
     * <p>
     * Pass this capability if you're creating IAM resources that have physical
     * names.
     * <p>
     * <code>CloudFormationCapabilities.NamedIAM</code> implies <code>CloudFormationCapabilities.IAM</code>; you don't have to pass both.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    NAMED_IAM,
    /**
     * (deprecated) Capability to run CloudFormation macros.
     * <p>
     * Pass this capability if your template includes macros, for example AWS::Include or AWS::Serverless.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    AUTO_EXPAND,
}
